<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Thalles Lázaro <thallesprofissional@gmail.com>
 * @author Daniel Dias Rodrigues <danieldiasr@gmail.com>
 * @author Paul Nizan <paul_nizan@hormail.com>
 * @author Eduardo Mozart de Oliveira <eduardomozart182@gmail.com>
 * @author ANDRE BASSANI DE FREITAS <dedebf@gmail.com>
 * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
 * @author Davi Jorge <davimoises2015@hotmail.com>
 * @author Schopf <pschopf@gmail.com>
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Márcio Gomes Gonçalves <gomes@metha.com.br>
 * @author Luis Fernando Enciso <lfenciso@certto.com.br>
 * @author Alauton/Loug
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luis@dantas.com>
 * @author Sergio Motta <sergio@cisne.com.br>
 * @author Isaias Masiero Filho <masiero@masiero.org>
 * @author Balaco Baco <balacobaco@imap.cc>
 * @author Victor Westmann <victor.westmann@gmail.com>
 * @author Leone Lisboa Magevski <leone1983@gmail.com>
 * @author Dário Estevão <darioems@gmail.com>
 * @author Juliano Marconi Lanigra <juliano.marconi@gmail.com>
 * @author Ednei <leuloch@gmail.com>
 * @author Hudson FAS <hudsonfas@gmail.com>
 * @author Guilherme Cardoso <guicardoso@gmail.com>
 * @author Viliam Dias <viliamjr@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar esta página';
$lang['btn_source']            = 'Mostrar código fonte';
$lang['btn_show']              = 'Mostrar página';
$lang['btn_create']            = 'Criar esta página';
$lang['btn_search']            = 'Pesquisar';
$lang['btn_save']              = 'Salvar';
$lang['btn_preview']           = 'Visualizar';
$lang['btn_top']               = 'Voltar ao topo';
$lang['btn_newer']             = '<< mais recente';
$lang['btn_older']             = 'menos recente >>';
$lang['btn_revs']              = 'Revisões anteriores';
$lang['btn_recent']            = 'Alterações recentes';
$lang['btn_upload']            = 'Enviar';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índice';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Entrar';
$lang['btn_logout']            = 'Sair';
$lang['btn_admin']             = 'Administrar';
$lang['btn_update']            = 'Atualizar';
$lang['btn_delete']            = 'Excluir';
$lang['btn_back']              = 'Voltar';
$lang['btn_backlink']          = 'Links reversos';
$lang['btn_subscribe']         = 'Monitorar alterações';
$lang['btn_profile']           = 'Atualizar o perfil';
$lang['btn_reset']             = 'Limpar';
$lang['btn_resendpwd']         = 'Definir a nova senha';
$lang['btn_draft']             = 'Editar o rascunho';
$lang['btn_recover']           = 'Recuperar o rascunho';
$lang['btn_draftdel']          = 'Excluir o rascunho';
$lang['btn_revert']            = 'Restaurar';
$lang['btn_register']          = 'Cadastre-se';
$lang['btn_apply']             = 'Aplicar';
$lang['btn_media']             = 'Gerenciador de mídias';
$lang['btn_deleteuser']        = 'Remover minha conta';
$lang['btn_img_backto']        = 'Voltar para %s';
$lang['btn_mediaManager']      = 'Ver no gerenciador de mídias';
$lang['loggedinas']            = 'Identificado(a) como:';
$lang['user']                  = 'Nome de usuário';
$lang['pass']                  = 'Senha';
$lang['newpass']               = 'Nova senha';
$lang['oldpass']               = 'Confirme a senha atual';
$lang['passchk']               = 'Outra vez';
$lang['remember']              = 'Lembre-se de mim';
$lang['fullname']              = 'Nome completo';
$lang['email']                 = 'E-mail';
$lang['profile']               = 'Perfil do usuário';
$lang['badlogin']              = 'Desculpe, mas o nome de usuário ou a senha estão incorretos.';
$lang['badpassconfirm']        = 'Desculpe, mas a senha está errada ';
$lang['minoredit']             = 'Alterações mínimas';
$lang['draftdate']             = 'O rascunho foi salvo automaticamente em';
$lang['nosecedit']             = 'A página foi modificada nesse intervalo de tempo. Como a informação da seção estava desatualizada, foi carregada a página inteira.';
$lang['searchcreatepage']      = 'Caso você não encontre o que está procurando, você pode criar ou editar a página %s, que recebeu esse nome após a sua pesquisa.';
$lang['search_fullresults']    = 'Resultados de texto inteiro';
$lang['js']['search_toggle_tools'] = 'Alternar as ferramentas de pesquisa';
$lang['js']['willexpire']      = 'O seu bloqueio de edição deste página irá expirar em um minuto.\nPara evitar conflitos de edição, clique no botão de visualização para reiniciar o temporizador de bloqueio.';
$lang['js']['notsavedyet']     = 'As alterações não salvas serão perdidas.
Deseja realmente continuar?';
$lang['js']['searchmedia']     = 'Buscar por arquivos';
$lang['js']['keepopen']        = 'Manter a janela aberta na seleção';
$lang['js']['hidedetails']     = 'Esconder detalhes';
$lang['js']['mediatitle']      = 'Configurações do Link';
$lang['js']['mediadisplay']    = 'Tipo de Link';
$lang['js']['mediaalign']      = 'Alinhamento';
$lang['js']['mediasize']       = 'Tamanho da Imagem';
$lang['js']['mediatarget']     = 'Alvo do Link';
$lang['js']['mediaclose']      = 'Fechar';
$lang['js']['mediainsert']     = 'Inserir';
$lang['js']['mediadisplayimg'] = 'Mostrar Imagem.';
$lang['js']['mediadisplaylnk'] = 'Mostrar apenas Link.';
$lang['js']['mediasmall']      = 'Versão Pequena';
$lang['js']['mediamedium']     = 'Versão Média';
$lang['js']['medialarge']      = 'Versão Grande';
$lang['js']['mediaoriginal']   = 'Versão Original';
$lang['js']['medialnk']        = 'Link para página de detalhes';
$lang['js']['mediadirect']     = 'Link direto para original';
$lang['js']['medianolnk']      = 'Sem Link';
$lang['js']['medianolink']     = 'Sem link na imagem';
$lang['js']['medialeft']       = 'Alinhamento de imagem a esquerda';
$lang['js']['mediaright']      = 'Alinhamento de imagem a direita';
$lang['js']['mediacenter']     = 'Alinhamento de imagem ao centro';
$lang['js']['medianoalign']    = 'Sem alinhamento';
$lang['js']['nosmblinks']      = 'Atalhos para pastas compartilhadas do Windows funcionam apenas no Microsoft Internet Explorer.
Entretanto, você ainda pode copiar e colar o atalho.';
$lang['js']['linkwiz']         = 'Link Wizard';
$lang['js']['linkto']          = 'Link para:';
$lang['js']['del_confirm']     = 'Deseja realmente excluir o(s) item(ns) selecionado(s)?';
$lang['js']['restore_confirm'] = 'Deseja realmente restaurar essa versão?';
$lang['js']['media_diff']      = 'Ver as diferenças:';
$lang['js']['media_diff_both'] = 'Lado a lado';
$lang['js']['media_diff_opacity'] = 'Sobreposição';
$lang['js']['media_diff_portions'] = 'Deslizamento';
$lang['js']['media_select']    = 'Selecione os arquivos...';
$lang['js']['media_upload_btn'] = 'Enviar';
$lang['js']['media_done_btn']  = 'Concluído';
$lang['js']['media_drop']      = 'Arraste os arquivos até aqui para enviar';
$lang['js']['media_cancel']    = 'remover';
$lang['js']['media_overwrt']   = 'Sobrescrever arquivos existentes';
$lang['js']['data_insecure']   = 'AVISO: Parece que seu diretório data não está corretamente seguro. Por favor, leia sobre <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki</a>.';
$lang['search_exact_match']    = 'Correspondência exata';
$lang['search_starts_with']    = 'Começa com';
$lang['search_ends_with']      = 'Termina com';
$lang['search_contains']       = 'Contém';
$lang['search_custom_match']   = 'Personalizar';
$lang['search_any_ns']         = 'Qualquer espaço de nomes';
$lang['search_any_time']       = 'Qualquer hora';
$lang['search_past_7_days']    = 'Semana passada';
$lang['search_past_month']     = 'Mês passado';
$lang['search_past_year']      = 'Ano passado';
$lang['search_sort_by_hits']   = 'Ordenar pelos acertos';
$lang['search_sort_by_mtime']  = 'Ordenar por última modificação';
$lang['regmissing']            = 'Desculpe, mas você precisa preencher todos os campos.';
$lang['reguexists']            = 'Desculpe, mas já existe um usuário com esse nome.';
$lang['regsuccess']            = 'O usuário foi criado e a senha enviada para seu e-mail.';
$lang['regsuccess2']           = 'O usuário foi criado.';
$lang['regfail']               = 'Não foi possível criar esse usuário.';
$lang['regmailfail']           = 'Aparentemente ocorreu um erro no envio da senha. Por favor, entre em contato com o administrador!';
$lang['regbadmail']            = 'O endereço de e-mail fornecido é, aparentemente, inválido - se você acha que isso é um erro, entre em contato com o administrador';
$lang['regbadpass']            = 'As senhas digitadas não são idênticas. Por favor, tente novamente.';
$lang['regpwmail']             = 'A sua senha do DokuWiki';
$lang['reghere']               = 'Ainda não tem uma conta? Crie uma';
$lang['profna']                = 'Esse wiki não suporta modificações do perfil.';
$lang['profnochange']          = 'Sem alterações, nada para fazer.';
$lang['profnoempty']           = 'Não são permitidos nomes ou endereços de e-mail em branco.';
$lang['profchanged']           = 'O perfil do usuário foi atualizado com sucesso.';
$lang['profnodelete']          = 'Esse wiki não suporta a exclusão de usuários ';
$lang['profdeleteuser']        = 'Excluir a conta';
$lang['profdeleted']           = 'Sua conta de usuário foi excluída desse wiki';
$lang['profconfdelete']        = 'Eu desejo remover minha conta dessa wiki. <br/> Essa ação não pode ser desfeita.';
$lang['profconfdeletemissing'] = 'Caixa de confirmação não marcada';
$lang['proffail']              = 'O perfil do usuário não foi atualizado.';
$lang['proftokenlegend']       = 'Token de Autenticação';
$lang['proftokengenerate']     = 'Redefinir Token';
$lang['proftokeninfo']         = 'O token de autenticação pode ser usado para permitir que aplicativos de terceiros façam login e atuem em seu nome.  A redefinição do token invalidará o antigo e desconectará todos os aplicativos que usaram o token anterior.';
$lang['pwdforget']             = 'Esqueceu sua senha? Solicite outra';
$lang['resendna']              = 'Esse wiki não tem suporte para o reenvio de senhas.';
$lang['resendpwd']             = 'Definir a nova senha para';
$lang['resendpwdmissing']      = 'Desculpe, você deve preencher todos os campos.';
$lang['resendpwdnouser']       = 'Desculpe, não foi possível encontrar esse usuário no nosso banco de dados.';
$lang['resendpwdbadauth']      = 'Desculpe, esse código de autorização é inválido. Certifique-se de que você usou o link de confirmação inteiro.';
$lang['resendpwdconfirm']      = 'Um link de confirmação foi enviado por e-mail.';
$lang['resendpwdsuccess']      = 'Sua nova senha foi enviada por e-mail.';
$lang['license']               = 'Exceto onde for informado ao contrário, o conteúdo neste wiki está sob a seguinte licença:';
$lang['licenseok']             = 'Observe: editando esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
$lang['searchmedia']           = 'Buscar arquivo:';
$lang['searchmedia_in']        = 'Buscar em %s';
$lang['txt_upload']            = 'Selecione o arquivo a ser enviado:';
$lang['txt_filename']          = 'Enviar como (opcional):';
$lang['txt_overwrt']           = 'Substituir o arquivo existente';
$lang['maxuploadsize']         = 'Tamanho máximo de %s por arquivo.';
$lang['allowedmime']           = 'Lista de extensões de arquivo permitidas';
$lang['lockedby']              = 'Atualmente bloqueada por:';
$lang['lockexpire']            = 'O bloqueio expira em:';
$lang['rssfailed']             = 'Ocorreu um erro durante a atualização dessa fonte: ';
$lang['nothingfound']          = 'Não foi encontrado nada.';
$lang['mediaselect']           = 'Arquivos de mídia';
$lang['uploadsucc']            = 'O envio foi efetuado com sucesso';
$lang['uploadfail']            = 'Não foi possível enviar o arquivo. Será algum problema com as permissões?';
$lang['uploadwrong']           = 'O envio foi bloqueado. Essa extensão de arquivo é proibida!';
$lang['uploadexist']           = 'O arquivo já existe. Não foi feito nada.';
$lang['uploadbadcontent']      = 'O conteúdo enviado não corresponde à extensão do arquivo %s.';
$lang['uploadspam']            = 'O envio foi bloqueado pela lista negra de spams.';
$lang['uploadxss']             = 'O envio foi bloqueado devido à possibilidade do seu conteúdo ser malicioso.';
$lang['uploadsize']            = 'O arquivo transmitido era grande demais. (max. %s)';
$lang['deletesucc']            = 'O arquivo "%s" foi excluído.';
$lang['deletefail']            = 'Não foi possível excluir "%s" - verifique as permissões.';
$lang['mediainuse']            = 'O arquivo "%s" não foi excluído - ele ainda está em uso.';
$lang['namespaces']            = 'Espaços de nomes';
$lang['mediafiles']            = 'Arquivos disponíveis em';
$lang['accessdenied']          = 'Você não tem permissão para visualizar esta página.';
$lang['mediausage']            = 'Use a seguinte sintaxe para referenciar esse arquivo:';
$lang['mediaview']             = 'Ver o arquivo original';
$lang['mediaroot']             = 'raiz';
$lang['mediaupload']           = 'Envie um arquivo para o espaço de nomes atual aqui. Para criar subespaços de nomes, preponha-os ao nome do arquivo no parâmetro "Enviar como", separados por dois pontos.';
$lang['mediaextchange']        = 'A extensão do arquivo mudou de .%s para .%s!';
$lang['reference']             = 'Referências para';
$lang['ref_inuse']             = 'O arquivo não pode ser excluído, porque ele ainda está sendo utilizado nas seguintes páginas:';
$lang['ref_hidden']            = 'Algumas referências estão em páginas que você não tem permissão para ler';
$lang['hits']                  = 'Resultados';
$lang['quickhits']             = 'Nomes de páginas coincidentes';
$lang['toc']                   = 'Tabela de conteúdos';
$lang['current']               = 'atual';
$lang['yours']                 = 'Sua versão';
$lang['diff']                  = 'Mostrar diferenças com a revisão atual';
$lang['diff2']                 = 'Mostrar diferenças entre as revisões selecionadas';
$lang['difflink']              = 'Link para esta página de comparações';
$lang['diff_type']             = 'Ver as diferenças:';
$lang['diff_inline']           = 'Mescladas';
$lang['diff_side']             = 'Lado a lado';
$lang['diffprevrev']           = 'Revisão anterior';
$lang['diffnextrev']           = 'Próxima revisão';
$lang['difflastrev']           = 'Última revisão';
$lang['diffbothprevrev']       = 'Ambos lados da revisão anterior';
$lang['diffbothnextrev']       = 'Ambos lados da revisão seguinte';
$lang['line']                  = 'Linha';
$lang['breadcrumb']            = 'Visitou:';
$lang['youarehere']            = 'Você está aqui:';
$lang['lastmod']               = 'Última modificação:';
$lang['by']                    = 'por';
$lang['deleted']               = 'removida';
$lang['created']               = 'criada';
$lang['restored']              = 'a revisão anterior foi restaurada (%s)';
$lang['external_edit']         = 'edição externa';
$lang['summary']               = 'Resumo da edição';
$lang['unknowndate']           = 'Data desconhecida';
$lang['noflash']               = 'O <a href="http://get.adobe.com/flashplayer">plug-in Adobe Flash</a> é necessário para exibir este conteúdo.';
$lang['download']              = 'Baixar o snippet';
$lang['tools']                 = 'Ferramentas';
$lang['user_tools']            = 'Ferramentas do usuário';
$lang['site_tools']            = 'Ferramentas do site';
$lang['page_tools']            = 'Ferramentas da página';
$lang['skip_to_content']       = 'ir para o conteúdo';
$lang['sidebar']               = 'Barra lateral';
$lang['mail_newpage']          = 'página adicionada:';
$lang['mail_changed']          = 'página modificada:';
$lang['mail_subscribe_list']   = 'páginas alteradas no espaço de nomes:';
$lang['mail_new_user']         = 'novo usuário:';
$lang['mail_upload']           = 'arquivo enviado:';
$lang['changes_type']          = 'Ver as mudanças de';
$lang['pages_changes']         = 'Páginas';
$lang['media_changes']         = 'Arquivos de mídia';
$lang['both_changes']          = 'Páginas e arquivos de mídia';
$lang['qb_bold']               = 'Texto em negrito';
$lang['qb_italic']             = 'Texto em itálico';
$lang['qb_underl']             = 'Texto sublinhado';
$lang['qb_code']               = 'Texto de código';
$lang['qb_strike']             = 'Texto tachado';
$lang['qb_h1']                 = 'Cabeçalho de nível 1';
$lang['qb_h2']                 = 'Cabeçalho de nível 2';
$lang['qb_h3']                 = 'Cabeçalho de nível 3';
$lang['qb_h4']                 = 'Cabeçalho de nível 4';
$lang['qb_h5']                 = 'Cabeçalho de nível 5';
$lang['qb_h']                  = 'Cabeçalho';
$lang['qb_hs']                 = 'Escolha o cabeçalho';
$lang['qb_hplus']              = 'Cabeçalho de nível mais alto';
$lang['qb_hminus']             = 'Cabeçalho de nível mais baixo';
$lang['qb_hequal']             = 'Cabeçalho de mesmo nível';
$lang['qb_link']               = 'Link interno';
$lang['qb_extlink']            = 'Link externo';
$lang['qb_hr']                 = 'Linha horizontal';
$lang['qb_ol']                 = 'Item de lista ordenada';
$lang['qb_ul']                 = 'Item de lista não ordenada';
$lang['qb_media']              = 'Adicionar imagens e/ou outros arquivos';
$lang['qb_sig']                = 'Inserir assinatura';
$lang['qb_smileys']            = 'Carinhas';
$lang['qb_chars']              = 'Caracteres especiais';
$lang['upperns']               = 'Pular para espaço de nomes acima';
$lang['metaedit']              = 'Editar metadados';
$lang['metasaveerr']           = 'Não foi possível escrever os metadados';
$lang['metasaveok']            = 'Os metadados foram salvos';
$lang['img_title']             = 'Título:';
$lang['img_caption']           = 'Descrição:';
$lang['img_date']              = 'Data:';
$lang['img_fname']             = 'Nome do arquivo:';
$lang['img_fsize']             = 'Tamanho:';
$lang['img_artist']            = 'Fotógrafo:';
$lang['img_copyr']             = 'Direitos autorais:';
$lang['img_format']            = 'Formato:';
$lang['img_camera']            = 'Câmera:';
$lang['img_keywords']          = 'Palavras-chave:';
$lang['img_width']             = 'Largura:';
$lang['img_height']            = 'Altura:';
$lang['subscr_subscribe_success'] = 'Adicionado %s à lista de monitoramentos de %s';
$lang['subscr_subscribe_error'] = 'Ocorreu um erro na adição de %s à lista de monitoramentos de %s';
$lang['subscr_subscribe_noaddress'] = 'Como não há nenhum endereço associado ao seu usuário, você não pode ser adicionado à lista de monitoramento';
$lang['subscr_unsubscribe_success'] = '%s foi removido da lista de monitoramento de %s';
$lang['subscr_unsubscribe_error'] = 'Ocorreu um erro na remoção de %s da lista de monitoramentos de %s';
$lang['subscr_already_subscribed'] = '%s já está monitorando %s';
$lang['subscr_not_subscribed'] = '%s não está monitorando %s';
$lang['subscr_m_not_subscribed'] = 'Você não está monitorando nem a página atual nem o espaço de nomes.';
$lang['subscr_m_new_header']   = 'Adicionar monitoramento';
$lang['subscr_m_current_header'] = 'Monitoramentos atuais';
$lang['subscr_m_unsubscribe']  = 'Cancelar monitoramento';
$lang['subscr_m_subscribe']    = 'Monitorar';
$lang['subscr_m_receive']      = 'Receber';
$lang['subscr_style_every']    = 'um e-mail a cada modificação';
$lang['subscr_style_digest']   = 'um agrupamento de e-mails com as mudanças para cada página (a cada %.2f dias)';
$lang['subscr_style_list']     = 'uma lista de páginas modificadas desde o último e-mail (a cada %.2f dias)';
$lang['authtempfail']          = 'A autenticação de usuários está temporariamente desabilitada. Se essa situação persistir, por favor, informe ao administrador do Wiki.';
$lang['i_chooselang']          = 'Selecione o seu idioma';
$lang['i_installer']           = 'Instalador do DokuWiki';
$lang['i_wikiname']            = 'Nome do Wiki';
$lang['i_enableacl']           = 'Habilitar Lista de Controle de Acessos (recomendado)';
$lang['i_superuser']           = 'Superusuário';
$lang['i_problems']            = 'O instalador encontrou alguns problemas, indicados abaixo. Você não pode continuar até corrigi-los.';
$lang['i_modified']            = 'Por questões de segurança, esse script funcionará apenas em uma instalação nova e não modificada do DokuWiki.
Você pode extrair novamente os arquivos do pacote original ou consultar as <a href="https://www.dokuwiki.org/install">instruções de instalação do DokuWiki</a>.';
$lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. O seu host a mantém desabilitada por algum motivo?';
$lang['i_disabled']            = 'Foi desativado pelo seu provedor.';
$lang['i_funcnmail']           = '<b>Nota:</b> A função de correio PHP não está disponível. %s Se permanecer indisponível, você pode instalar o <a href="https://www.dokuwiki.org/plugin:smtp">plugin SMTP</a>.';
$lang['i_phpver']              = 'A sua versão do PHP (<code>%s</code>) é inferior à necessária (<code>%s</code>). Você precisa atualizar a sua instalação do PHP.';
$lang['i_mbfuncoverload']      = 'mbstring.func_overload precisa ser desabilitado no php.ini para executar o DokuWiki';
$lang['i_urandom']             = 'O DokuWiki não pode criar números criptograficamente seguros para cookies. Você pode verificar as configurações do open_basedir no php.ini para obter o acesso <code> / dev / urandom </code> adequado.';
$lang['i_permfail']            = 'O DokuWiki não tem permissão de escrita em <code>%s</code>. Você precisa corrigir as configurações de permissão nesse diretório!';
$lang['i_confexists']          = '<code>%s</code> já existe';
$lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É necessário checar as permissões de arquivos/diretórios e criar o arquivo manualmente.';
$lang['i_badhash']             = 'dokuwiki.php não reconhecido ou modificado (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor ilegal ou em branco';
$lang['i_success']             = 'A configuração terminou com sucesso. Agora você deve excluir o arquivo install.php. Conheça o seu <a href="doku.php?id=wiki:welcome">novo DokuWiki</a>!';
$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita dos arquivos de configuração. É necessário corrigi-los manualmente antes de usar seu <a href="doku.php?id=wiki:welcome">novo DokuWiki</a>';
$lang['i_policy']              = 'Política inicial de permissões';
$lang['i_pol0']                = 'Wiki aberto (leitura, escrita e envio de arquivos por todos)';
$lang['i_pol1']                = 'Wiki público (leitura por todos, escrita e envio de arquivos por usuários registrados)';
$lang['i_pol2']                = 'Wiki fechado (leitura, escrita e envio de arquivos somente por usuários registrados)';
$lang['i_allowreg']            = 'Permite usuários se registrarem';
$lang['i_retry']               = 'Tentar novamente';
$lang['i_license']             = 'Por favor escolha a licença que voce deseja utilizar para seu conteúdo:';
$lang['i_license_none']        = 'Não mostrar nenhuma informação da licença';
$lang['i_pop_field']           = 'Por favor, nos ajude a melhorar sua experiência com DokuWiki:';
$lang['i_pop_label']           = 'Uma vez por mês, enviar anonimamente informações de uso de dados para os desenvolvedores DokuWiki';
$lang['recent_global']         = 'Você está observando as alterações dentro do espaço de nomes <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
$lang['years']                 = '%d anos atrás';
$lang['months']                = '%d meses atrás';
$lang['weeks']                 = '%d semanas atrás';
$lang['days']                  = '%d dias atrás';
$lang['hours']                 = '%d horas atrás';
$lang['minutes']               = '%d minutos atrás';
$lang['seconds']               = '%d segundos atrás';
$lang['wordblock']             = 'Suas mudanças não foram salvas pois contem texto bloqueados (spam)';
$lang['media_uploadtab']       = 'Enviar';
$lang['media_searchtab']       = 'Pesquisar';
$lang['media_file']            = 'Arquivo';
$lang['media_viewtab']         = 'Ver';
$lang['media_edittab']         = 'Editar';
$lang['media_historytab']      = 'Histórico';
$lang['media_list_thumbs']     = 'Miniaturas';
$lang['media_list_rows']       = 'Linhas';
$lang['media_sort_name']       = 'Nome';
$lang['media_sort_date']       = 'Data';
$lang['media_namespaces']      = 'Selecione o espaço de nomes';
$lang['media_files']           = 'Arquivos em %s';
$lang['media_upload']          = 'Enviar para %s';
$lang['media_search']          = 'Pesquisar em %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s em %s';
$lang['media_edit']            = 'Editar %s';
$lang['media_history']         = 'Histórico de %s';
$lang['media_meta_edited']     = 'o metadado foi editado';
$lang['media_perm_read']       = 'Desculpe, mas você não tem privilégios suficientes para ler arquivos.';
$lang['media_perm_upload']     = 'Desculpe, mas você não tem privilégios suficientes para enviar arquivos.';
$lang['media_update']          = 'Enviar uma nova versão';
$lang['media_restore']         = 'Restaurar esta versão';
$lang['media_acl_warning']     = 'Essa lista pode não estar completa devido a restrições de ACL e páginas ocultas.';
$lang['email_fail']            = 'PHP mail () ausente ou desativado. O seguinte email não foi enviado:';
$lang['currentns']             = 'Domínio atual';
$lang['searchresult']          = 'Resultado da Busca';
$lang['plainhtml']             = 'HTML simples';
$lang['wikimarkup']            = 'Marcação wiki';
$lang['page_nonexist_rev']     = 'Página não encontrada em %s. Foi criada posteriormente em <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Impossível analisar em "%s".';
$lang['email_signature_text']  = 'Essa mensagem foi gerada pelo DokuWiki em
@DOKUWIKIURL@';
$lang['log_file_too_large']    = 'Arquivo de registro muito grande. As linhas anteriores foram ignoradas!';
$lang['log_file_failed_to_open'] = 'Falha ao abrir o arquivo de log.';
$lang['log_file_failed_to_read'] = 'Ocorreu um erro ao ler o log.';
